{% load menu_tags %}

<ul class="breadcrumb">
    {% for ance in ancestors %}
        <li>{% if not forloop.last %}<a href="{{ ance.get_absolute_url }}">{{ ance.get_menu_title }}</a> &raquo; {% else %}{{ ance.get_menu_title }}{% endif %}</li>
    {% endfor %}
</ul>
