/* styles related to django-cms standard plugins */

// Styles for the picture plugin

.align-right {
    display: block;
    text-align: right;
}

.align-left {
    display: block;
    text-align: left;
}

.align-center {
    display: block;
    text-align: center;
}
