/* styles for the album and picture page */

.album-title {
    display: block;
    overflow: hidden;
    white-space: nowrap;
    text-overflow: ellipsis;
    margin-top: 10px;
}

.album {
    text-align: center;
    margin-top: 10px;
}

.album-description {
    margin-top: 10px;
}
