{% load staticfiles %}
{% load sekizai_tags %}
{% load menu_tags %}
{% load i18n %}
{% load compress %}
{% load socialschools_tags %}
{% load cms_tags %}

<!DOCTYPE html>
<html>
    {% include "socialschools_cms/includes/head.html" %}
    <body>
        <div class="footer-row">
            <div class="topbar-theme-12">
                <div class="stripe-theme-12 stripe-1"></div>
                <div class="stripe-theme-12 stripe-2"></div>
                <div class="stripe-theme-12 stripe-3"></div>
                <div class="stripe-theme-12 stripe-1"></div>
                <div class="stripe-theme-12 stripe-2"></div>
                <div class="container">
                    <div class="logo-theme-12 pull-left">
                        <span class="helper"></span>
                        {% placeholder "Logo Plugin" inherit %}
                    </div>
                    {% placeholder "Login" inherit %}
                </div>
            </div>
            <div class="navbar">
                <div class="navbar-inner css-navbar">
                    <div class="container">
                    {% block navbar%}
                    <ul class="nav">
                        {% show_menu 0 0 0 100 "socialschools_cms/menu/menu.html" %}
                    </ul>
                    {% endblock %}
                    </div>
                </div>
            </div>
        </div>
        <div class="footer-row-expand">
            <div class="container">
                {% block wrapper %}
                {% endblock %}
            </div>
        </div>

        <footer class="footer-row css-footer">
            {% block footer %}
            <div class="container">
                {% show_menu 0 1 1 100 "socialschools_cms/includes/footer.html" %}
            </div>
            {% endblock %}
        </footer>
        <script type="text/javascript" src="{% static 'js/jquery.1.9.1.min.js' %}"></script>
        <script type="text/javascript" src="{% static 'js/bootstrap.min.js' %}"></script>
        <script type="text/javascript" src="{% static 'js/socialschools-cms.js' %}"></script>
        {% render_block 'js' %}
    </body>
</html>
