/* sticky footer styles */

html, body {
    height: 100%;
    margin: 0px;
}

body {
    display: table;
    width: 100%;
    .box-sizing(border-box);
}

.footer-row {
    display: table-row;
    height: 1px;
}

.footer-row-expand {
    display: table-row;
    height: 100%;
}

/* media queries for footer-row */

@media (max-width: 980px) {
    .footer-row, .footer-row-expand {
        display: block;
        height: auto;
    }
}

@media (max-width: 768px) {
    .css-footer {
        margin-left: -20px;
        margin-right: -20px;
    }
}

.css-footer {
    background: @grayLighter;
    .container {
        padding: 0 20px 20px 20px;
    }
    img {
        max-width: 120px;
    }
}

/* style for footer links */

.item-list {
    margin-top: 20px;
}

.main-item {
    font-weight: bold;
    display: block;
    color: @gray;
}

.sub-item {
    font-size: 12px;
    display: block;
    color: @grayLight;
}
