/* Overrides for bootstrap classes */

/* overrides primary button colors to match theme */

.btn-primary {
    .buttonBackground(@themeColor, @themeSecondary);
    .buttonLinkColor(@themeColor);
    &.active {
      .buttonLinkColor(@themeColor);
    }
}

.btn-primary:hover {
    .buttonLinkHoverColor(@themeColor);
}

.btn-success {
    .buttonBackground(lighten(#52b42b, 10%), #52b42b);
}

/* stacked nav for content pages in theme 1 and 2 */

.nav-stacked {
    li {
        a:hover {
            background-color: fadeout(@themeColor, 95%);
        }
    }
    .active {
        a {
            background-color: fadeout(@themeColor, 95%);
        }
        a:hover {
            background-color: fadeout(@themeColor, 95%);
        }
    }
}

/* Overrides for dropdown menu */

// Hover/Focus state
// -----------
.dropdown-menu > li > a:hover,
.dropdown-menu > li > a:focus,
.dropdown-submenu:hover > a,
.dropdown-submenu:focus > a {
    text-decoration: none;
    color: @themeColor;
    background: @grayLighter;
}

// Active state
// ------------
.dropdown-menu > .active > a,
.dropdown-menu > .active > a:hover,
.dropdown-menu > .active > a:focus {
    color: @themeColor;
    text-decoration: none;
    outline: 0;
    background: none;
}

.navbar .nav li.dropdown.open .dropdown-toggle {
    background-color: @grayLighter;
    color: @black;
}

.navbar .nav li.dropdown.active > .dropdown-toggle {
    background-color:  @white;
}


/* other overrides */

.form-actions {
    background: none;
    border: 0;
}

.controls {
    ul {
        list-style: none;
        margin-left: 0px;
    }
}

