<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
    <meta name="csrf-token" content="{{csrf_token}}">

    <title>{% block _title %}{% endblock %}</title>

    <meta name="description" content="{% block _description %}{% endblock %}">
    <meta name="keywords" content="{% block _keywords %}{% endblock %}">
    <meta name="author" content="Changer">

    {% if debug %}
        <link rel="stylesheet/less" type="text/css" href="{% static 'css/styles.less' %}">
        <script src="{% static 'js/less.1.3.3.min.js' %}"></script>
    {% else %}
        <link rel="stylesheet" type="text/css" href="{% static 'css/styles.css' %}">
    {% endif %}

    {% render_block 'css' %}
</head>
