{% extends "socialschools_cms/theme_12_base.html" %}
{% load cms_tags %}
{% load staticfiles %}

{% block wrapper%}
    <div class="row-fluid">
        <div class="span12">
            <div class="css-content-white main-content">
                <div class="row-fluid">
                    <div class="span5">
                        {% placeholder welcome_block_left %}
                    </div>
                    <div class="span7">
                        <div class="circle">
                            {% placeholder welcome_block_right %}
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <div class="row-fluid">
        <div class="span8">
            <div class="css-content-white content-block widget-4">
                {% include "socialschools_cms/includes/news.html" %}
            </div>
        </div>
        <div class="span4">
            <div class="css-content-white content-block widget-1">
                {% placeholder widget_block_1 %}
            </div>
            <div class="css-content-white content-block widget-2">
                {% placeholder widget_block_2 %}
            </div>
        </div>
    </div>

{% endblock %}

