/* styles for cms-widgets */

.widget-1, .widget-2, .widget-3 {
    h1, h2, h3, h4, h5 {
        margin-bottom: 10px;
        margin-top: 0px;
        padding-bottom: 10px;
        border-bottom: 1px solid @grayLighter;
    }
}

.widget-1 {
    border-top: 3px solid @cmsColorPrimary;
}

.widget-2 {
    border-top: 3px solid @cmsColorSecondary;
}

.widget-3 {
    border-top: 3px solid @themeColor;
}

.widget-4 {
    border-top: 3px solid @themeColor;
}
