{% extends "socialschools_cms/theme_12_base.html" %}
{% load cms_tags %}
{% load staticfiles %}

{% block wrapper%}
    <div class="row-fluid">
        <div class="span12">
            <div class="css-carousel-slider main-content">
                <div class="row-fluid css-gallery-slider">
                    <div class="span12">
                        {% placeholder image_gallery %}
                        <div class="css-carousel-description">
                            <div class="css-carousel-description-background"></div>
                            <div class="css-carousel-description-text">{% placeholder image_gallery_text %}</div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <div class="row-fluid">
        <div class="span6 welcome-intro-left">
            {% placeholder welcome_block_left %}
        </div>
        <div class="span6 welcome-intro-right">
            <div class="content-block">
                {% include "socialschools_cms/includes/news.html" %}
            </div>
        </div>
    </div>

{% endblock %}

