{% load staticfiles %}

<div class="row">
{% for child in children %}
        <div class="span2 item-list">
            <a href="{{ child.get_absolute_url }}" class="main-item">{{ child.get_menu_title }}</a>
            {% for child in child.children %}
                <a href="{{ child.get_absolute_url }}" class="sub-item">{{ child.get_menu_title }}</a>
            {% endfor %}
        </div>
    {% if forloop.counter|divisibleby:"6" and not forloop.counter.last %}
        </div>
        <div class="row">
    {% endif %}
{% endfor %}
</div>
<hr>
<span class="meta-info">powered by </span>&nbsp;&nbsp; <a href="http://www.socialschools.nl/nl" target="blank"><img src="{% static 'css/img/social-schools-logo.png' %}"></a>
