/* styling for different navbars */

// generic styles for all themes

//// styles for centering school-logo

.helper {
  display: inline-block;
  height: 100%;
  vertical-align: middle;
}
.school-logo {
  max-width: 400px;
  vertical-align: middle;
}

.css-login {
  margin-top: 24px;
  margin-bottom: 24px;
  .btn {
    margin-top: 0px;
  }
}

//// media queries to override bootstraps full width navbar container

@media (min-width: 1200px) {
    .css-navbar .container {
        width:1170px;
    }
}
@media (min-width: 979px) and (max-width: 1200px) {
    .css-navbar .container {
        width:960px;
    }
}
@media (min-width: 768px) and (max-width: 979px) {
    .css-navbar .container {
        width:724px;
    }
}




/* boostrap overrides for top navbar theme 1 and 2 */

.navbar-inner {
    .border-radius(0px);
    border: none;
    border-bottom: 1px solid darken(@themeSecondary, 10%);
    #gradient > .vertical(@themeColor, @themeSecondary);
    .nav {
        li {
            a {
                .buttonLinkColor(@themeColor);
                text-shadow: none;
            }
        }
        .active {
            a {
                background-color: @themeColor !important;
                .buttonLinkColor(@themeColor);
                font-weight: bold;
                .box-shadow(0 3px 8px rgba(0,0,0,0.35) inset);
            }
        }
    }
}


/* navbar styles for theme 1 and 2 */

.stripe-1 {
    background: @themeColor;
}

.stripe-2 {
    background: @cmsColorBlue;
}

.stripe-3 {
    background: @cmsColorGreen;
}

.stripe-theme-12 {
    float: left;
    width: 20%;
    height: 2px;
}

.topbar-theme-12 {
  background: @white;
  .logo-theme-12 {
    height: 80px;
    .school-logo {
      max-height: 60px;
    }
  }
}


/* bootstrap overrides for top navbar theme 3 */

.navbar-theme-3 .container > .navbar-nav li > a,
.navbar-theme-4 .container > .navbar-nav li > a, {
    background-color: @white;
    .box-shadow(none);
}

/* navbar styles for theme 3 */

.navbar-theme-3,
.navbar-theme-4 {
  background-color: white;
  border-bottom: 1px solid #eeeeee;
  height: 109px;
  .logo-theme-3,
  .logo-theme-4 {
    display: block;
  }
  .btn-navbar {
    color: @themeColor;
    text-shadow: none;
    background: none;
    margin-top: 18px;
    &:hover {
      background: none;
      color: @themeColor;
    }
  }
  .nav > li > a {
    line-height: 58px;
    color: black;
    font-weight: bold;
    font-size: 14px;
    &:hover {
      background-color: @grayLighter;
      color: @black;
    }
  }
  .nav > li.active > a {
    color: @themeColor;
    border-bottom: 3px solid @themeColor;
    background-color: @white;
    .box-shadow(none) !important;
    &:hover {
      background-color: @grayLighter;
    }
  }
  .dropdown-menu > li > a {
    line-height: 36px;
    border-bottom: none !important;
    color: @themeColor;
  }
  .theme-3-login-bar,
  .theme-4-login-bar {
    text-align: right;
    border-bottom: 1px solid @grayLighter;
    color: @themeColor;
    font-weight: bold;
    a {
      line-height: 28px;
      font-size: 11px;
      text-transform: uppercase;
    }
  }
}

.logo-theme-3-expandable.logo-expanded {
  height: 160px;
  padding-right: 25px;
  padding-left: 25px;
  margin-left: -25px;
  background-image: url("img/theme-3-topbar-mask.png");
  background-repeat: no-repeat;
  background-position: center 30px;
  .school-logo {
    max-height: 95px;
    margin-top: -30px;
    max-width: 200px;
  }
}

.logo-theme-4 .school-logo {
  max-height: 80px;
}

@media (max-width: 980px) {
  .navbar-theme-3,
  .navbar-theme-4 {
    height: auto;
  }
  .navbar-header-theme-3 {
    .logo-theme-3-expandable.logo-expanded {
      height: 80px;
      .school-logo {
        height: 40px;
        margin-top: 0px;
      }
    }
  }
  .navbar-header-theme-4 {
    .logo-theme-4 {
      height: 80px;
      .school-logo {
        height: 40px;
        margin-top: 0px;
      }
    }
  }
}

@media (min-width: 768px) and (max-width: 980px) {
  .navbar-header-theme-3 {
    padding-left: 20px;
  }
}

@media (min-width: 981px) {
  .navbar-header-theme-3 {
    .logo-theme-3-expandable.logo-expanded {
      min-width: 200px;
      text-align: center;
    }
  }
}

.logo-theme-3-expandable.logo-collapsed,
.logo-theme-3 {
  height: 80px;
  .school-logo {
    height: 40px;
  }
}

.logo-theme-3-expandable,
.school-logo {
  transition: all 0.25s;
  -moz-transition: all 0.25s; /* Firefox 4 */
  -webkit-transition: all 0.25s; /* Safari and Chrome */
  -o-transition: all 0.25s; /* Opera */
}

.login-theme-3,
.login-theme-4 {
  float: right !important;
}

.theme-3-login-bar,
.theme-4-login-bar {
    height: 28px;
}

@media (max-width: 980px) {
  .navbar-theme-3,
  .navbar-theme-4 {
    padding: 0px 20px;
    margin-bottom: 0px;
  }
}

