{% extends "socialschools_cms/base.html" %}
{% load i18n %}

{% block wrapper %}
	<h2>{% trans 'Something went wrong' %}</h2>
	<p>{% trans 'We have been informed about the problem.' %}</p>
{% endblock %}
