{% load staticfiles %}
{% load sekizai_tags %}
{% load menu_tags %}
{% load i18n %}
{% load compress %}
{% load socialschools_tags %}
{% load cms_tags %}

<!DOCTYPE html>
<html>
    {% include "socialschools_cms/includes/head.html" %}
    <body class="theme-4">
        <div class="footer-row">
            <div class="navbar navbar-fixed-top navbar-theme-4">
                <div class="theme-4-login-bar">
                    <div class="container">
                        {% placeholder "Login" inherit %}
                    </div>
                </div>
                <div class="container">
                    <a class="btn-navbar collapsed" data-toggle="collapse" data-target=".nav-collapse">
                        <i class="fa fa-navicon fa-2x"></i>
                    </a>
                    <div class="navbar-header navbar-header-theme-4">
                        <a class="logo-theme-4 pull-left" href="#">
                            <span class="helper"></span>
                            {% placeholder "Logo Plugin" inherit %}
                        </a>
                    </div>
                {% block navbar %}
                    <div class="nav-collapse collapse">
                        <ul class="nav">
                            {% show_menu 0 1 1 100 "socialschools_cms/menu/menu_dropdown.html" %}
                        </ul>
                    </div>
                {% endblock %}
                </div>
            </div>
        </div>
        <div class="footer-row-expand">
            {% block wrapper %}
            {% endblock %}
        </div>

        <footer class="footer-row css-footer">
            {% block footer %}
            <div class="container">
                {% show_menu 0 1 1 100 "socialschools_cms/includes/footer.html" %}
            </div>
            {% endblock %}
        </footer>

        {% compress js %}
            {% if debug %}
                <script type="text/javascript" src="{% static 'js/jquery.1.9.1.min.js' %}"></script>
                <script type="text/javascript" src="{% static 'js/jquery.colorbox.js' %}"></script>
                <script type="text/javascript" src="{% static 'js/bootstrap.min.js' %}"></script>
                <script type="text/javascript" src="{% static 'js/socialschools-cms.js' %}"></script>
                <script type="text/javascript" src="{% static 'js/multitenant.js' %}"></script>
                <script type="text/javascript" src="{% static 'js/theme3-topbar.js' %}"></script>
                <script type="text/javascript" src="{% static 'js/bootstrap-hover-dropdown.min.js' %}"></script>
            {% else %}
                <script type="text/javascript" src="{% static 'js/multitenant-cms.min.js' %}"></script>
            {% endif %}
        {% endcompress %}
        {% render_block 'js' %}
        {% placeholder "Google Analytics" inherit %}
    </body>
</html>
