{% extends "socialschools_cms/theme_3_base.html" %}
{% load staticfiles %}
{% load sekizai_tags %}
{% load menu_tags %}
{% load i18n %}
{% load compress %}
{% load socialschools_tags %}
{% load cms_tags %}

{% block wrapper %}
    <div class="carousel-theme-3">
        {% placeholder carousel %}
        <div class="carousel-theme-3-mask">
        </div>
        <div class="container">
            {% placeholder carousel-tagline %}
        </div>
    </div>
    <div class="container">
        <div class="row pillars-theme-3">
            <div class="span12">
                {% placeholder pillars %}
            </div>
        </div>
        <div class="row-fluid">
            <div class="span6">
                <h2>Nieuws</h2>
                <div class="news-theme-3">
                {% placeholder news %}
                </div>
            </div>
            <div class="span6">
                {% placeholder banners %}
            </div>
        </div>
        <hr>
        <h2>Uitgelicht</h2>
        <div class="row-fluid row-banners">
            <div class="span3 banner-themecolor">
                {% placeholder bottom-banner-1 %}
            </div>
            <div class="span3 banner-primarycolor">
                {% placeholder bottom-banner-2 %}
            </div>
            <div class="span3 banner-themecolor">
                {% placeholder bottom-banner-3 %}
            </div>
            <div class="span3 banner-primarycolor">
                {% placeholder bottom-banner-4 %}
            </div>
        </div>
    </div>
{% endblock %}
