{% extends "socialschools_cms/theme_4_base.html" %}
{% load cms_tags %}
{% load menu_tags %}

{% block wrapper %}
    <div class="breadcrumb-theme-3">
        <div class="container">
            <div class="pull-right">
                {% show_breadcrumb "socialschools_cms/menu/breadcrumb.html" %}
            </div>
        </div>
    </div>
    <div class="container">
        <div class="row">
            <div class="span9 border-right content-theme-3">
                <div class="main-content">
                    <div class="row-fluid">
                        {% if current_page.children.exists or request.current_page.level > 0 %}
                            <div class="span4">
                                <ul class="nav nav-tabs nav-stacked">
                                {% show_menu 1 100 0 100 "socialschools_cms/menu/menu.html" %}
                                </ul>
                            </div>
                            <div class="span8">
                                {% placeholder content_block_1 %}
                            </div>
                        {% else %}
                            <div class="span12">
                                {% placeholder content_block_1 %}
                            </div>
                        {% endif %}
                    </div>
                </div>
            </div>
            <div class="span3 widgets-theme-3">
                <div class="row-fluid">
                    {% placeholder widget_block_1 %}
                </div>
            </div>
        </div>
    </div>
{% endblock %}

